require "import"
import "java.text.SimpleDateFormat"
import "java.util.Date"
import "android.content.Context"
import "android.content.Intent"
import "android.content.IntentFilter"
import "android.os.BatteryManager"
import "android.os.Environment"
import "android.os.StatFs"
import "android.provider.Settings"
import "android.os.Build"
import "android.bluetooth.BluetoothAdapter"
import "android.location.LocationManager"

-- Get current time
local formattedTime = SimpleDateFormat("hh:mm a").format(Date())

-- Get current date
local formattedDate = SimpleDateFormat("MMMM dd, yyyy").format(Date())

-- Get battery level
local batteryIntent = this.registerReceiver(nil, IntentFilter(Intent.ACTION_BATTERY_CHANGED))
local level = batteryIntent.getIntExtra(BatteryManager.EXTRA_LEVEL, -1)
local scale = batteryIntent.getIntExtra(BatteryManager.EXTRA_SCALE, -1)
local batteryPercent = (level / scale) * 100

-- Get battery health
local health = batteryIntent.getIntExtra(BatteryManager.EXTRA_HEALTH, -1)
local batteryHealth = "Unknown"
if health == BatteryManager.BATTERY_HEALTH_GOOD then
    batteryHealth = "Good"
elseif health == BatteryManager.BATTERY_HEALTH_OVERHEAT then
    batteryHealth = "Overheat"
elseif health == BatteryManager.BATTERY_HEALTH_DEAD then
    batteryHealth = "Dead"
elseif health == BatteryManager.BATTERY_HEALTH_OVER_VOLTAGE then
    batteryHealth = "Over Voltage"
elseif health == BatteryManager.BATTERY_HEALTH_UNSPECIFIED_FAILURE then
    batteryHealth = "Unspecified Failure"
elseif health == BatteryManager.BATTERY_HEALTH_COLD then
    batteryHealth = "Cold"
end

-- Get charging status
local status = batteryIntent.getIntExtra(BatteryManager.EXTRA_STATUS, -1)
local isCharging = status == BatteryManager.BATTERY_STATUS_CHARGING or status == BatteryManager.BATTERY_STATUS_FULL

-- Get available storage
local storage = Environment.getExternalStorageDirectory()
local stat = StatFs(storage.getPath())
local availableBytes = stat.getAvailableBytes()
local availableGB = availableBytes / (1024^3)

-- Get current temperature
local temperature = batteryIntent.getIntExtra(BatteryManager.EXTRA_TEMPERATURE, 0) / 10

-- Get screen brightness
local brightness = Settings.System.getInt(this.getContentResolver(), Settings.System.SCREEN_BRIGHTNESS)
local brightnessPercent = (brightness / 255) * 100

-- Get memory card status
local isMemoryCardInserted = Environment.getExternalStorageState() == Environment.MEDIA_MOUNTED

-- Get device name
local deviceName = Build.MODEL

-- Get Bluetooth status
local bluetoothAdapter = BluetoothAdapter.getDefaultAdapter()
local bluetoothStatus = bluetoothAdapter and (bluetoothAdapter.isEnabled() and "on" or "off") or "not available"

-- Get network connection status
local connectivityManager = this.getSystemService(Context.CONNECTIVITY_SERVICE)
local activeNetworkInfo = connectivityManager.getActiveNetworkInfo()
local isConnected = activeNetworkInfo and activeNetworkInfo.isConnected
local internetStatus = isConnected and "connected" or "disconnected"

-- Get Airplane mode status
local isAirplaneModeOn = Settings.System.getInt(this.getContentResolver(), Settings.Global.AIRPLANE_MODE_ON, 0) == 1
local airplaneModeStatus = isAirplaneModeOn and "on" or "off"

-- Get Location status
local locationManager = this.getSystemService(Context.LOCATION_SERVICE)
local isLocationEnabled = locationManager.isProviderEnabled(LocationManager.GPS_PROVIDER)
local locationStatus = isLocationEnabled and "enabled" or "disabled"

-- Create and speak the message
local chargingStatusMessage = isCharging and "Device is charging." or "Device is not charging."

local message = "The time is " .. formattedTime ..
                ", the date is " .. formattedDate ..
                ", the battery level is " .. string.format("%.0f", batteryPercent) .. "%" ..
                ", battery health is " .. batteryHealth ..
                (isCharging and ". Device is charging." or ". Device is not charging.") ..
                ", available storage is " .. string.format("%.2f", availableGB) .. " GB" ..
                ", temperature is " .. temperature .. "°C" ..
                ", screen brightness is " .. string.format("%.0f", brightnessPercent) .. "%" ..
                ", memory card is " .. (isMemoryCardInserted and "inserted" or "not inserted") ..
                ", device name is " .. deviceName ..
                ", Bluetooth is currently " .. bluetoothStatus ..
                ", internet status is " .. internetStatus ..
                ", Airplane mode is " .. airplaneModeStatus ..
                ", Location status is " .. locationStatus

this.speak(message)
return true